/*
 * WiPal - A library and a set of tools to manipulate wireless traces.
 * Copyright (C) 2007, 2008  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */
#ifndef TOOL_MICROSECONDS_HXX_
# define TOOL_MICROSECONDS_HXX_

# include <cassert>

# include <wipal/tool/gmp_64_wrapper.hh>

# include "microseconds.hh"

namespace tool
{

  inline
  microseconds::microseconds(const uint64_t i):
    mpz_class (tool::mpz_of_uint64(i))
  {
  }

  inline
  microseconds::microseconds(const struct timeval& tv): mpz_class (tv.tv_sec)
  {
    *this *= 1000000;
    *this += tv.tv_usec;
  }

  inline
  microseconds::microseconds(const mpz_type& z): mpz_class (z)
  {
  }

  template <class T1, class T2>
  microseconds::microseconds(const __gmp_expr<T1, T2>& e): mpz_class (e)
  {
  }

  inline
  uint32_t
  microseconds::get_prism_mactime() const
  {
    return sgn(*this) < 0? -get_ui(): get_ui();
  }

  inline
  uint32_t
  microseconds::get_prism_hosttime() const
  {
    mpz_type	r = *this / 10;

    return sgn(r) < 0? -r.get_ui(): r.get_ui();
  }

  inline
  uint64_t
  microseconds::get_uint64() const
  {
    return tool::uint64_of_mpz(*this);
  }

  inline
  unsigned
  microseconds::get_div_by(unsigned d) const
  {
    assert(sgn(*this) >= 0);

    mpz_type	r = *this / d;

    assert(r.fits_uint_p());
    return r.get_ui();
  }

  inline
  struct timeval
  microseconds::get_timeval() const
  {
    struct timeval	r;
    mpz_type		q;

    r.tv_usec = mpz_fdiv_q_ui(q.get_mpz_t(), get_mpz_t(), 1000000);
    assert(q.fits_sint_p());
    r.tv_sec = q.get_si();

    return r;
  }

} // End of namespace tool.

#endif // TOOL_MICROSECONDS_HXX_
