
/*
 * WiPal - A library and a set of tools to manipulate wireless traces.
 * Copyright (C) 2007, 2008  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */
#ifndef WIFI_FRAME_DISSECTOR_DEFAULT_HOOKS_HXX_
# define WIFI_FRAME_DISSECTOR_DEFAULT_HOOKS_HXX_

# include "default_hooks.hh"

namespace wifi
{

  namespace frame
  {

    /*---------------------.
    | Invalid frames hooks |
    `---------------------*/

    inline
    void
    dissector_default_hooks::
    invalid_type_or_subtype_hook(const void*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::invalid_type_hook(const void*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::invalid_subtype_hook(const void*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::
    invalid_management_subtype_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    invalid_control_subtype_hook(const void*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    invalid_data_subtype_hook(const void*, size_t, status)
    {
    }

    /*------------.
    | Basic hooks |
    `------------*/

    inline
    void
    dissector_default_hooks::frame_hook(const void*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    addr_hook(const void*, size_t, unsigned, const addr&)
    {
    }

    inline
    void
    dissector_default_hooks::
    seq_ctl_hook(const void*, size_t, unsigned, unsigned)
    {
    }

    inline
    void
    dissector_default_hooks::
    qos_ctl_hook(const void*, size_t, unsigned, bool, unsigned, unsigned)
    {
    }

    inline
    void
    dissector_default_hooks::end_of_frame_headers_hook(const void*,
						       size_t,
						       const void*)
    {
    }

    inline
    void
    dissector_default_hooks::end_of_frame_hook(const void*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::management_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::control_hook(const void*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::data_hook(const void*, size_t)
    {
    }

    /*-----------------.
    | Truncation hooks |
    `-----------------*/

    inline
    void
    dissector_default_hooks::truncated_frame_hook(const void*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::truncated_unknown_frame_hook(const void*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    truncated_management_frame_hook(const mgt::header*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::
    truncated_ps_poll_frame_hook(const ctl::ps_poll::header*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::
    truncated_rts_frame_hook(const ctl::rts::header*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::
    truncated_cf_end_frame_hook(const ctl::cf_end::header*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::
    truncated_cf_end_cf_ack_frame_hook(const ctl::cf_end_cf_ack::header*,
				       size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::
    truncated_cts_frame_hook(const ctl::cts::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    truncated_ack_frame_hook(const ctl::ack::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    truncated_data_frame_hook(const void*, size_t, status)
    {
    }

    /*-----------------.
    | Management hooks |
    `-----------------*/


    // Field hooks.


    inline
    void
    dissector_default_hooks::management_addr1_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::management_addr2_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::management_addr3_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    management_seq_ctl_hook(const mgt::header*, size_t, unsigned, unsigned)
    {
    }


    // Inidividual frame subtypes.


    inline
    void
    dissector_default_hooks::beacon_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::assoc_req_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::assoc_resp_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::reassoc_req_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::reassoc_resp_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::probe_req_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::probe_resp_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::atim_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::disassoc_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::auth_hook(const mgt::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::deauth_hook(const mgt::header*, size_t)
    {
    }


    /*--------------.
    | Control hooks |
    `--------------*/


    // Individual frame subtypes.


    inline
    void
    dissector_default_hooks::ps_poll_hook(const ctl::ps_poll::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::rts_hook(const ctl::rts::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::cf_end_hook(const ctl::cf_end::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    cf_end_cf_ack_hook(const ctl::cf_end_cf_ack::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::cts_hook(const ctl::cts::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::ack_hook(const ctl::ack::header*, size_t)
    {
    }


    // Field hooks //


    // PS Poll.

    inline
    void
    dissector_default_hooks::
    ps_poll_addr1_hook(const ctl::ps_poll::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    ps_poll_addr2_hook(const ctl::ps_poll::header*, size_t)
    {
    }


    // RTS.

    inline
    void
    dissector_default_hooks::rts_addr1_hook(const ctl::rts::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::rts_addr2_hook(const ctl::rts::header*, size_t)
    {
    }


    // CF-End.

    inline
    void
    dissector_default_hooks::
    cf_end_addr1_hook(const ctl::cf_end::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    cf_end_addr2_hook(const ctl::cf_end::header*, size_t)
    {
    }


    // CF-End + CF-Ack.

    inline
    void
    dissector_default_hooks::
    cf_end_cf_ack_addr1_hook(const ctl::cf_end_cf_ack::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    cf_end_cf_ack_addr2_hook(const ctl::cf_end_cf_ack::header*, size_t)
    {
    }


    // CTS.

    inline
    void
    dissector_default_hooks::
    cts_addr1_hook(const ctl::ack::header*, size_t)
    {
    }


    // Ack.

    inline
    void
    dissector_default_hooks::ack_addr1_hook(const ctl::ack::header*, size_t)
    {
    }


    /*-----------.
    | Data hooks |
    `-----------*/


    // Field hooks.


    inline
    void
    dissector_default_hooks::data_addr1_hook(const void*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::data_addr2_hook(const void*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::data_addr3_hook(const void*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::data_addr4_hook(const void*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    data_seq_ctl_hook(const void*, size_t, unsigned, unsigned)
    {
    }


    // Individual frame subtypes.

    inline
    void
    dissector_default_hooks::data_only_hook(const void*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::data_cf_ack_hook(const void*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::data_cf_poll_hook(const void*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::
    data_cf_ack_cf_poll_hook(const void*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::null_hook(const void*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::cf_ack_hook(const void*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::cf_poll_hook(const void*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::cf_ack_cf_poll_hook(const void*, size_t, status)
    {
    }

    inline
    void
    dissector_default_hooks::
    within_ibss_hook(const data::within_ibss::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    from_ds_hook(const data::from_ds::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    to_ds_hook(const data::to_ds::header*, size_t)
    {
    }

    inline
    void
    dissector_default_hooks::
    ap_to_ap_hook(const data::ap_to_ap::header*, size_t)
    {
    }

  } // End of namespace wifi::frame.

} // End of namespace wifi.

#endif // ! WIFI_FRAME_DISSECTOR_DEFAULT_HOOKS_HXX_
