/*
 * WiPal - A library and a set of tools to manipulate wireless traces.
 * Copyright (C) 2007, 2008  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */
#ifndef WIFI_FRAME_FILTER_REFERENCE_BLACKLIST_HH_
# define WIFI_FRAME_FILTER_REFERENCE_BLACKLIST_HH_

# include <set>

# include <wipal/tool/filter.hh>

/*---------------------.
| Forward declarations |
`---------------------*/

namespace wifi
{
  namespace frame
  {
    namespace filter
    {

      namespace internals
      {
	struct blacklist_predicate;
      }

      template <class, class>
      struct reference_blacklist;

    }
  }
}

/*--------------.
| Virtual types |
`--------------*/

namespace tool
{

#define WP_wff	wifi::frame::filter
#define WP_wffi	WP_wff::internals

  template <class I, class B>
  struct types< WP_wff::reference_blacklist<I, B> >:
    public types< tool::filter<I, WP_wffi::blacklist_predicate,
			       WP_GET_EXACT(B,
					    WP_wff::reference_blacklist<I,
									B>)> >
  {
  };

#undef WP_wff
#undef WP_wffi

} // End of namespace tool.


/*-------------.
| Declarations |
`-------------*/


namespace wifi
{
  namespace frame
  {
    namespace filter
    {

      namespace internals
      {

	struct blacklist_predicate
	{
	  typedef std::pair<unsigned, unsigned>		blacklist_item;
	  typedef std::set<blacklist_item>		blacklist;

	  blacklist_predicate(const blacklist& l);

	  template <class T>
	  bool
	  operator () (const T& item) const;

	private:
	  blacklist	blacklist_;
	};

      } // End of namespace wifi::frame::filter::internals.

      template <class InputIterator, class B = tool::bottom>
      struct reference_blacklist:
	public tool::filter<InputIterator, internals::blacklist_predicate,
			    WP_GET_EXACT(B,
					 reference_blacklist<InputIterator, B>)>
      {
	typedef
	tool::filter<InputIterator, internals::blacklist_predicate,
		     WP_GET_EXACT(B, reference_blacklist<InputIterator, B>)>
								super_type;
	typedef std::set< std::pair<unsigned, unsigned> >	blacklist;

	reference_blacklist(const InputIterator&	first,
			    const InputIterator&	last,
			    const blacklist&		l);
      };

    } // End of namespace wifi::frame::filter.

  } // End of namespace wifi::frame.

} // End of namespace wifi.

# include "reference_blacklist.hxx"

#endif // ! WIFI_FRAME_FILTER_SIMPLE_MERGE_HH_
