/*
 * WiPal - A library and a set of tools to manipulate wireless traces.
 * Copyright (C) 2008  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */
#ifndef WIFI_FRAME_STATS_DELIMITER_FRAMES_HXX_
# define WIFI_FRAME_STATS_DELIMITER_FRAMES_HXX_

# include <boost/date_time/posix_time/posix_time_duration.hpp>
# include <boost/date_time/posix_time/ptime.hpp>
# include <boost/date_time/posix_time/time_formatters.hpp>

# include <wipal/wifi/frame/stats/delimiter_frames.hh>

namespace wifi
{

  namespace frame
  {

    namespace stats
    {
      inline
      void
      delimiter_frames::restart()
      {
	earliest_ = latest_ = boost::none_t ();
      }

      inline
      void
      delimiter_frames::account_frame(const tool::microseconds&	phy_stamp,
				      const struct timeval&	pcap_stamp)
      {
	if (not earliest_ or earliest_->first > phy_stamp)
	  earliest_ = stamp_pair (phy_stamp, pcap_stamp);

	if (not latest_ or latest_->first < phy_stamp)
	  latest_ = stamp_pair (phy_stamp, pcap_stamp);
      }

      inline
      std::ostream&
      delimiter_frames::print(std::ostream& o) const
      {
	print(o, "earliest", earliest_);
	print(o, "latest", latest_);
	return o << std::flush;
      }

      std::ostream&
      delimiter_frames::print(std::ostream&			o,
			      const std::string&		type,
			      const optional_stamp_pair&	value)
      {
	o << type << " frame TOA: ";

	if (not value)
	  o << "NA";
	else
	  {
	    using namespace boost::gregorian;
	    using namespace boost::posix_time;

	    const ptime	t (date(1970, Jan, 01),
			   seconds (value->second.tv_sec) +
			   microseconds (value->second.tv_usec));

	    o << to_simple_string(t) << " UTC";
	  }

	return o << '\n';
      }


    } // End of namespace wifi::frame::stats.

  } // End of namespace wifi::frame.

} // End of namespace wifi.

#endif // ! WIFI_FRAME_STATS_DELIMITER_FRAMES_HXX_
