/*
 * WiPal - A library and a set of tools to manipulate wireless traces.
 * Copyright (C) 2008  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */
#ifndef WIFI_FRAME_STATS_GROWTH_HH_
# define WIFI_FRAME_STATS_GROWTH_HH_

# include <wipal/wifi/frame/stats/epoch_tracker.hh>
# include <wipal/wifi/frame/stats/abstract_stats.hh>

namespace wifi
{

  namespace frame
  {

    namespace stats
    {

      template <class T, unsigned EpochLength>
      struct growth: public abstract_stats
      {
	void		restart();
	void		update(const tool::microseconds& timestamp);
	void		update(const T& elt);
	std::ostream&	print(std::ostream& o) const;

      private:
	struct epoch_data
	{
	  epoch_data();

	  unsigned	total_count;
	  unsigned	current_count;
	};

	std::set<T>				elements_;
	std::set<T>				current_elements_;
	epoch_tracker<epoch_data, EpochLength>	tracker_;
      };

    } // End of namespace wifi::frame::stats.

  } // End of namespace wifi::frame.

} // End of namespace wifi.

# include "growth.hxx"

#endif // ! WIFI_FRAME_STATS_GROWTH_HH_
